==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-AsZxJZlgAK04EzaOGx2H3T
key: prettyprinter-convert-ansi-wl-pprint-1.1-AsZxJZlgAK04EzaOGx2H3T
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: 25a30a2023fb4281ed7622af9feecdcc
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-AsZxJZlgAK04EzaOGx2H3T
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    prettyprinter-1.3.0-3usJJlw0RU6A9CFsaFSROY
    prettyprinter-ansi-terminal-1.1.1.2-Hd9K3btG3vMGwjaLg4nuU0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-BViwuCRCr8ZHn45imDXsZ7
key: prettyprinter-convert-ansi-wl-pprint-1.1-BViwuCRCr8ZHn45imDXsZ7
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: 73fbc6fa2a69bfa2e837751932dda5fd
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-BViwuCRCr8ZHn45imDXsZ7
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    prettyprinter-1.3.0-Hk7YxusyFZ4CBPO5K9XlPv
    prettyprinter-ansi-terminal-1.1.1.2-1kfkUrENVbg6idGM8o7Zsa
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
